@@ -183,7 +183,7 @@ def deploy(settings_path=None, **settings_patches):
             abort('Cannot find gitignore file at {path}'.format(path=gitignore_path))
 
         # Copy it
-        rsync_argument = '-rlpctzD --exclude .git --exclude-from \'{path}\''.format(
+        rsync_argument = '-rLpctzD --exclude .git --exclude-from \'{path}\''.format(
             path=os.path.relpath(gitignore_path))
         local(rsync(project_source_root, tmp_directory, rsync_argument=rsync_argument, expand_to_destination=True))
 
