@@ -135,7 +135,9 @@ def setup(settings_path=None, **settings_patches):
         global_uwsgi_ini_template_path = os.path.join(BEANSTALK_ROOT_PATH, 'static/global_uwsgi.ini')
         with hide('everything'):
             uid = local('id -u apache', capture=True)
-        global_uwsgi_ini_content = render_file(global_uwsgi_ini_template_path, beanstalk_settings, BEANSTALK_UID=uid)
+            gid = local('id -g apache', capture=True)
+        global_uwsgi_ini_content = render_file(
+            global_uwsgi_ini_template_path, beanstalk_settings, BEANSTALK_UID=uid, BEANSTALK_GID=gid)
         with open(global_uwsgi_ini_path, 'w') as f:
             f.write(global_uwsgi_ini_content)
 
@@ -216,6 +218,7 @@ def create_app(project_name, settings_path=None, **settings_patches):
     local('mkdir -p %s' % project_base)
     local('mkdir -p %s' % project_source)
     local('mkdir -p %s' % project_logs)
+    local('setfacl -m u:apache:rwx %s' % project_logs)
 
     # Initialize venv
     if not os.path.exists(project_venv):
@@ -386,6 +389,7 @@ def install_app(project_name, settings_path=None, **settings_patches):
     # Remove options
     must_remove_options = [
         'uid',
+        'gid',
         'http',
         'https',
         'http-proxy',
